inferpy.layers package
======================

Submodules
----------

inferpy.layers.sequential module
--------------------------------

.. automodule:: inferpy.layers.sequential
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: inferpy.layers
   :members:
   :undoc-members:
   :show-inheritance:
